# Tool Configuration
## Available tools

### Wolfram Alpha
1. Register wolfram alpha app account and activate [APP ID](https://developer.wolframalpha.com/access)  
2. Setup Wolfram Alpha APP_ID
```bash
export WOLFRAM_ALPHA_APPID=<YOUR_APP_ID>
```

### Rapid API Tool
1. Register for [Rapid API](https://rapidapi.com/hub)
2. Click into the tool page that you want to call and click the (`Subscribe to Test`) button to activate tools.
3. Setup up Rapid API Key
```bash
export RAPID_API_KEY=<YOUR_RAPID_API_KEY>
```
#### Current supported Rapid API tools
- [Words API](https://rapidapi.com/dpventures/api/wordsapi/)
- [Moon Phase](https://rapidapi.com/MoonAPIcom/api/moon-phase/)
- [Trip Advisor](https://rapidapi.com/DataCrawler/api/tripadvisor16)
- [Shazam](https://rapidapi.com/apidojo/api/shazam/)
- [IMDB](https://rapidapi.com/rapihub-rapihub-default/api/imdb-top-100-movies/)


